using System;
using System.Collections.Generic;
using System.Text;
using System.Resources;
using System.Web;
using System.Web.Profile;
using System.Web.UI;
using System.Collections;
using Mediachase.Commerce.Customers.Profile;
using Mediachase.Commerce.Security;
using Mediachase.Commerce.Engine;
using Mediachase.Commerce.Engine.Navigation;
using Mediachase.Commerce.Pricing;
using Mediachase.Commerce.Markets;

namespace Mediachase.Commerce.Website.BaseControls
{
    /// <summary>
    /// Base class for all user controls in the CMS System. Adds additional properties which are common
    /// for website project but not available for web application projects.
    /// </summary>
    public class BaseStoreUserControl : UserControl
    {
        /// <summary>
        /// Gets the RM.
        /// </summary>
        /// <value>The RM.</value>
        public StoreResourceManager RM
        {
            get
            {
                return new StoreResourceManager();
            }
        }

        /// <summary>
        /// Gets the profile.
        /// </summary>
        /// <value>The profile.</value>
        public CustomerProfileWrapper Profile
        {
            get
            {
                return GetCurrentUserProfile() as CustomerProfileWrapper;
            }
        }

		public IPriceService PricingService
		{
			get { return EPiServer.ServiceLocation.ServiceLocator.Current.GetInstance<IPriceService>(); }
		}

		public IMarket Market
		{
			get 
			{
				IMarketService marketService = EPiServer.ServiceLocation.ServiceLocator.Current.GetInstance<IMarketService>();
				return marketService.GetMarket(MarketId.Default);
			}
		}

        /// <summary>
        /// Initializes a new instance of the <see cref="T:UserControlBase"/> class.
        /// </summary>
        public BaseStoreUserControl()
        {
        }

        /// <summary>
        /// Converts a URL into one that is usable on the requesting client.
        /// </summary>
        /// <param name="relativeUrl">The URL associated with the <see cref="P:System.Web.UI.Control.TemplateSourceDirectory"/> property.</param>
        /// <returns>The converted URL.</returns>
        /// <exception cref="T:System.ArgumentNullException">
        /// Occurs if the <paramref name="relativeUrl"/> parameter contains null.
        /// </exception>
        public new string ResolveUrl(string relativeUrl)
        {
#pragma warning disable 618
            return UrlService.ResolveUrl(this, relativeUrl);
#pragma warning restore 618
        }

        private ProfileBase GetCurrentUserProfile()
        {
            // This method has a strong dependency on ProfileBase and may not be unit tested.
            var httpProfile = HttpContext.Current.Profile;
            var profile = httpProfile == null ? null : new CustomerProfileWrapper(httpProfile);
            return profile;
        }
    }

    /// <summary>
    /// 
    /// </summary>
    public class StoreResourceManager
    {
        /// <summary>
        /// Gets the string.
        /// </summary>
        /// <param name="name">The name.</param>
        /// <returns></returns>
        public string GetString(string name)
        {
            string str = "";
            try
            {
                str = System.Web.HttpContext.GetGlobalResourceObject("StoreResources", name, System.Threading.Thread.CurrentThread.CurrentUICulture).ToString();
            }
            catch
            {
                try
                {
                    object obj = System.Web.HttpContext.GetGlobalResourceObject("StoreResources", name);
                    if (obj == null)
                        throw new MissingManifestResourceException(String.Format("Resource for key {0} was not found.", name), null);

                    str = obj.ToString();
                }
                catch (System.Resources.MissingManifestResourceException ex)
                {

                    throw new MissingManifestResourceException(String.Format("Resource for key {0} was not found.", name), ex);
                }
            }
            return str;
        }
    }
}
